Welcome to the OppiaMobile documentation — OppiaMobile 0.1.31 documentation

### Navigation

- index
- next |
- OppiaMobile 0.1.31 documentation »

# Welcome to the OppiaMobile documentation

OppiaMobile-Server is the server side component for the OppiaMobile learning application

Contents:

- Installation
- Local Settings
- Upgrading
- REST API
- Utilities
- Change Log

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- OppiaMobile 0.1.31 documentation »